@@ -5,8 +5,8 @@ import (
 	"path/filepath"
 
 	"github.com/apex/log"
+	"github.com/goreleaser/goreleaser/internal/yaml"
 	"github.com/goreleaser/goreleaser/pkg/context"
-	yaml "gopkg.in/yaml.v2"
 )
 
 // Pipe that writes the effective config file to dist.
