@@ -27,7 +27,7 @@ import (
 )
 
 const (
-	defaultNameTemplate = "{{ .PackageName }}_{{ .Version }}_{{ .Os }}_{{ .Arch }}{{ if .Arm }}v{{ .Arm }}{{ end }}{{ if .Mips }}_{{ .Mips }}{{ end }}"
+	defaultNameTemplate = `{{ .PackageName }}_{{ .Version }}_{{ .Os }}_{{ .Arch }}{{ with .Arm }}v{{ . }}{{ end }}{{ with .Mips }}_{{ . }}{{ end }}{{ if not (eq .Amd64 "v1") }}{{ .Amd64 }}{{ end }}`
 	extraFiles          = "Files"
 )
 
@@ -54,11 +54,6 @@ func (Pipe) Default(ctx *context.Context) error {
 		if fpm.FileNameTemplate == "" {
 			fpm.FileNameTemplate = defaultNameTemplate
 		}
-		if len(fpm.Builds) == 0 { // TODO: change this to empty by default and deal with it in the filtering code
-			for _, b := range ctx.Config.Builds {
-				fpm.Builds = append(fpm.Builds, b.ID)
-			}
-		}
 		ids.Inc(fpm.ID)
 	}
 
@@ -81,11 +76,16 @@ func (Pipe) Run(ctx *context.Context) error {
 }
 
 func doRun(ctx *context.Context, fpm config.NFPM) error {
-	linuxBinaries := ctx.Artifacts.Filter(artifact.And(
+	filters := []artifact.Filter{
 		artifact.ByType(artifact.Binary),
 		artifact.ByGoos("linux"),
-		artifact.ByIDs(fpm.Builds...),
-	)).GroupByPlatform()
+	}
+	if len(fpm.Builds) > 0 {
+		filters = append(filters, artifact.ByIDs(fpm.Builds...))
+	}
+	linuxBinaries := ctx.Artifacts.
+		Filter(artifact.And(filters...)).
+		GroupByPlatform()
 	if len(linuxBinaries) == 0 {
 		return fmt.Errorf("no linux binaries found for builds %v", fpm.Builds)
 	}
@@ -118,7 +118,9 @@ func mergeOverrides(fpm config.NFPM, format string) (*config.NFPMOverridables, e
 }
 
 func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*artifact.Artifact) error {
-	arch := binaries[0].Goarch + binaries[0].Goarm + binaries[0].Gomips
+	// TODO: improve mips handling on nfpm
+	infoArch := binaries[0].Goarch + binaries[0].Goarm + binaries[0].Gomips // key used for the ConventionalFileName et al
+	arch := infoArch + binaries[0].Goamd64                                  // unique arch key
 
 	overridden, err := mergeOverrides(fpm, format)
 	if err != nil {
@@ -191,7 +193,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 		for _, ov := range fpm.Deb.Lintian {
 			lines = append(lines, fmt.Sprintf("%s: %s", fpm.PackageName, ov))
 		}
-		lintianPath := filepath.Join(ctx.Config.Dist, "deb", fpm.PackageName, ".lintian")
+		lintianPath := filepath.Join(ctx.Config.Dist, "deb", fpm.PackageName+"_"+arch, ".lintian")
 		if err := os.MkdirAll(filepath.Dir(lintianPath), 0o755); err != nil {
 			return fmt.Errorf("failed to write lintian file: %w", err)
 		}
@@ -199,7 +201,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 			return fmt.Errorf("failed to write lintian file: %w", err)
 		}
 
-		log.Infof("creating %q", lintianPath)
+		log.Debugf("creating %q", lintianPath)
 		contents = append(contents, &files.Content{
 			Source:      lintianPath,
 			Destination: filepath.Join("./usr/share/lintian/overrides", fpm.PackageName),
@@ -231,7 +233,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 	log.WithField("files", destinations(contents)).Debug("all archive files")
 
 	info := &nfpm.Info{
-		Arch:            arch,
+		Arch:            infoArch,
 		Platform:        "linux",
 		Name:            fpm.PackageName,
 		Version:         ctx.Version,
@@ -350,12 +352,14 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 		return fmt.Errorf("could not close package file: %w", err)
 	}
 	ctx.Artifacts.Add(&artifact.Artifact{
-		Type:   artifact.LinuxPackage,
-		Name:   name,
-		Path:   path,
-		Goos:   binaries[0].Goos,
-		Goarch: binaries[0].Goarch,
-		Goarm:  binaries[0].Goarm,
+		Type:    artifact.LinuxPackage,
+		Name:    name,
+		Path:    path,
+		Goos:    binaries[0].Goos,
+		Goarch:  binaries[0].Goarch,
+		Goarm:   binaries[0].Goarm,
+		Gomips:  binaries[0].Gomips,
+		Goamd64: binaries[0].Goamd64,
 		Extra: map[string]interface{}{
 			artifact.ExtraBuilds: binaries,
 			artifact.ExtraID:     fpm.ID,
